@@ -9,24 +9,17 @@ from PyGine.Transform import Transform
 class DrawCircleComponent(Component) :
     def __init__(self,parent,color,InitialRadius=1 ) :
         super().__init__(parent)
-
-
-
         self.parent = parent
-
         self.transform = Transform()
         self.transform.scale.x = InitialRadius
-
-
         self.color = color
 
     def start(self):
         pass
 
     def update(self,dt) :
-
-        pg.draw.circle(Game.get().surface,self.color,(int((self.parent.transform.position.x + self.transform.position.x) - (Camera.DX+Camera.PX)),
-                         int((self.parent.transform.position.y +self.transform.position.y) - (Camera.DY+Camera.PY)) ) , self.transform.scale.x*Camera.ZX)
+        pg.draw.circle(Game.get().surface,self.color,(int((self.parent.relativeTransform.position.x + self.relativeTransform.position.x) - (Camera.DX+Camera.PX)*(not self.parent.fixed)),
+                         int((self.parent.relativeTransform.position.y +self.relativeTransform.position.y) - (Camera.DY+Camera.PY)*(not self.parent.fixed)) ) , self.relativeTransform.scale.x*Camera.ZX*(not self.parent.fixed))
 
 
     def getSprite(self) :
